"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Input = Input;

var _objectWithoutProperties2 = _interopRequireDefault(require("@babel/runtime/helpers/esm/objectWithoutProperties"));

var _react = _interopRequireDefault(require("react"));

var _core = require("@material-ui/core");

var _md = require("react-icons/md");

var _reactNumberFormat = _interopRequireDefault(require("react-number-format"));

var _styles = require("../../shared/styles");

var StyledTextField = (0, _core.styled)(_core.TextField)({
  "& label.Mui-focused": {
    color: _styles.colors.amulet
  },
  "& .MuiInput-underline:after": {
    borderBottomColor: _styles.colors.amulet
  },
  "& .MuiOutlinedInput-root": {
    "&:hover fieldset": {
      borderColor: _styles.colors.amulet
    },
    "&.Mui-focused fieldset": {
      borderColor: _styles.colors.amulet
    }
  }
});
var useStyles = (0, _core.makeStyles)({
  required: {
    "& fieldset": {
      borderColor: _styles.colors.negative
    }
  }
});

var CustomInput = function CustomInput(_ref) {
  var props = Object.assign({}, _ref);
  var classes = useStyles();
  return props.isNumeric ? /*#__PURE__*/_react.default.createElement(_reactNumberFormat.default, Object.assign({
    type: "numeric",
    className: props.required && !props.value && classes.required,
    customInput: StyledTextField,
    format: props.mask,
    thousandSeparator: ".",
    decimalSeparator: ",",
    prefix: props.prefix,
    suffix: props.suffix
  }, props)) : /*#__PURE__*/_react.default.createElement(StyledTextField, Object.assign({
    className: props.required && !props.value && classes.required
  }, props));
};
/**
- Default input component
**/


function Input(_ref2) {
  var inputId = _ref2.inputId,
      value = _ref2.value,
      label = _ref2.label,
      helperText = _ref2.helperText,
      errorText = _ref2.errorText,
      error = _ref2.error,
      handleChange = _ref2.handleChange,
      fullWidth = _ref2.fullWidth,
      textArea = _ref2.textArea,
      minRows = _ref2.minRows,
      maxRows = _ref2.maxRows,
      Icon = _ref2.icon,
      size = _ref2.size,
      placeholder = _ref2.placeholder,
      avatar = _ref2.avatar,
      avatarName = _ref2.avatarName,
      isNumeric = _ref2.isNumeric,
      type = _ref2.type,
      mask = _ref2.mask,
      format = _ref2.format,
      prefix = _ref2.prefix,
      suffix = _ref2.suffix,
      avatarTitle = _ref2.avatarTitle,
      props = (0, _objectWithoutProperties2.default)(_ref2, ["inputId", "value", "label", "helperText", "errorText", "error", "handleChange", "fullWidth", "textArea", "minRows", "maxRows", "icon", "size", "placeholder", "avatar", "avatarName", "isNumeric", "type", "mask", "format", "prefix", "suffix", "avatarTitle"]);

  function createTextWithIcon() {
    return /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, !error && helperText && /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, /*#__PURE__*/_react.default.createElement(_md.MdInfoOutline, {
      style: {
        fontSize: "13px"
      }
    }), "\xA0"), error ? errorText : helperText);
  }

  function handleSize() {
    if (size === "small") return "40px";
    if (size === "medium") return "50px";
  }

  return /*#__PURE__*/_react.default.createElement(_core.Grid, {
    container: true,
    spacing: avatar ? 1 : 0,
    title: avatarTitle
  }, avatar && /*#__PURE__*/_react.default.createElement(_core.Grid, {
    item: true,
    lg: 2
  }, /*#__PURE__*/_react.default.createElement("div", {
    style: {
      display: "flex",
      justifyContent: "center",
      alignItems: "center",
      height: "100%"
    }
  }, /*#__PURE__*/_react.default.createElement(_core.Avatar, {
    style: {
      backgroundColor: _styles.colors.amulet,
      fontSize: "".concat(_styles.typography.size.s1, "px")
    }
  }, avatarName))), /*#__PURE__*/_react.default.createElement(_core.Grid, {
    item: true,
    lg: avatar ? 10 : 12
  }, /*#__PURE__*/_react.default.createElement(CustomInput, Object.assign({}, props, {
    isNumeric: isNumeric,
    format: format,
    mask: mask,
    prefix: prefix,
    suffix: suffix,
    type: type,
    multiline: textArea,
    minRows: minRows,
    maxRows: maxRows,
    inputProps: {
      style: {
        padding: "0 14px 0 14px",
        height: handleSize(),
        fontFamily: _styles.typography.type.secondary,
        resize: textArea ? "vertical" : "none",
        fontSize: "".concat(size === "small" ? _styles.typography.size.s1 : _styles.typography.size.s3, "px")
      }
    },
    size: size,
    fullWidth: fullWidth,
    id: inputId,
    label: label,
    placeholder: placeholder,
    helperText: createTextWithIcon(),
    variant: "outlined",
    error: error,
    value: value,
    name: inputId,
    onChange: function onChange(e) {
      return handleChange(e);
    },
    InputProps: {
      endAdornment: Icon && /*#__PURE__*/_react.default.createElement(_core.InputAdornment, {
        position: "end"
      }, /*#__PURE__*/_react.default.createElement(Icon, null))
    }
  }))));
}

Input.defaultProps = {
  inputId: "defaultId",
  label: null,
  helperText: "",
  errorText: "",
  error: false,
  fullWidth: false,
  textArea: false,
  minRows: 1,
  maxRows: 1,
  icon: null,
  size: "medium",
  placeholder: null,
  avatar: false,
  avatarName: "",
  isNumeric: false,
  type: "text",
  avatarTitle: ""
};