"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

var _interopRequireWildcard = require("@babel/runtime/helpers/interopRequireWildcard");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Table = Table;

var _slicedToArray2 = _interopRequireDefault(require("@babel/runtime/helpers/esm/slicedToArray"));

var _taggedTemplateLiteral2 = _interopRequireDefault(require("@babel/runtime/helpers/esm/taggedTemplateLiteral"));

var _defineProperty2 = _interopRequireDefault(require("@babel/runtime/helpers/esm/defineProperty"));

var _react = _interopRequireWildcard(require("react"));

var _core = require("@material-ui/core");

var _icons = require("@material-ui/icons");

var _Pagination = require("../Pagination");

var _Input = require("../Input");

var _styledComponents = _interopRequireWildcard(require("styled-components"));

var _styles = require("../../shared/styles");

var _templateObject, _templateObject2, _templateObject3, _templateObject4, _templateObject5, _templateObject6, _templateObject7, _templateObject8, _templateObject9;

/**
 * Table header cell component
 * @param {object} props
 * @returns HeaderCell
 */
function HeaderCell(_ref) {
  var column = _ref.column,
      center = _ref.center,
      ordering = _ref.ordering,
      onChangeOrder = _ref.onChangeOrder;
  var orderAvailable = (0, _react.useMemo)(function () {
    var _ordering$availableOr;

    return (ordering === null || ordering === void 0 ? void 0 : (_ordering$availableOr = ordering.availableOrderBy) === null || _ordering$availableOr === void 0 ? void 0 : _ordering$availableOr.some(function (o) {
      return o === column.id;
    })) || false;
  }, [ordering, column]);
  var props = (0, _react.useMemo)(function () {
    var ordered = (ordering === null || ordering === void 0 ? void 0 : ordering.order_by) === column.id;
    var order = ordered ? ordering === null || ordering === void 0 ? void 0 : ordering.order : null;
    return (0, _defineProperty2.default)({
      sorting: orderAvailable
    }, order, true);
  }, [orderAvailable, ordering, column]);
  var onOrder = (0, _react.useCallback)(function () {
    if (!orderAvailable) return;

    var getOrder = function getOrder() {
      if (column.id === (ordering === null || ordering === void 0 ? void 0 : ordering.order_by)) {
        var isAsc = (ordering === null || ordering === void 0 ? void 0 : ordering.order) === "asc";
        return isAsc ? "desc" : "asc";
      }

      return "asc";
    };

    var order = getOrder();
    onChangeOrder({
      order_by: column.id,
      order: order
    });
  }, [onChangeOrder, column, ordering, orderAvailable]);
  return /*#__PURE__*/_react.default.createElement(TableCell, Object.assign({
    key: column.id,
    center: center,
    textBold: true,
    onClick: onOrder
  }, props), /*#__PURE__*/_react.default.createElement("p", {
    style: {
      margin: "0px",
      color: "#8A8A8A",
      fontWeight: 600,
      fontSize: "14px",
      lineHeight: "22px"
    }
  }, column.title));
}

var TableCell = (0, _styledComponents.default)(_core.TableCell)(_templateObject || (_templateObject = (0, _taggedTemplateLiteral2.default)(["\n  font-family: ", " !important;\n  font-size: ", "px !important;\n  border-bottom: 0 !important;\n\n  ", "\n\n  ", "\n\n  ", "\n"])), _styles.typography.type.secondary, _styles.typography.size.s2, function (_ref3) {
  var textBold = _ref3.textBold;
  return textBold && (0, _styledComponents.css)(_templateObject2 || (_templateObject2 = (0, _taggedTemplateLiteral2.default)(["\n      font-weight: ", " !important;\n    "])), _styles.typography.weight.bold);
}, function (_ref4) {
  var center = _ref4.center;
  return center && (0, _styledComponents.css)(_templateObject3 || (_templateObject3 = (0, _taggedTemplateLiteral2.default)(["\n      text-align: center !important;\n    "])));
}, function (_ref5) {
  var sorting = _ref5.sorting,
      asc = _ref5.asc,
      desc = _ref5.desc;
  return sorting && (0, _styledComponents.css)(_templateObject4 || (_templateObject4 = (0, _taggedTemplateLiteral2.default)(["\n      position: relative;\n      padding-right: 30px !important;\n      cursor: pointer;\n\n      ::before {\n        content: \"\\2191\";\n        position: absolute;\n        right: 1em;\n        bottom: 18px;\n        opacity: 0.3;\n        display: block;\n      }\n\n      ::after {\n        content: \"\\2193\";\n        position: absolute;\n        right: 0.5em;\n        bottom: 18px;\n        opacity: 0.3;\n        display: block;\n      }\n\n      ", "\n\n      ", "\n    "], ["\n      position: relative;\n      padding-right: 30px !important;\n      cursor: pointer;\n\n      ::before {\n        content: \"\\\\2191\";\n        position: absolute;\n        right: 1em;\n        bottom: 18px;\n        opacity: 0.3;\n        display: block;\n      }\n\n      ::after {\n        content: \"\\\\2193\";\n        position: absolute;\n        right: 0.5em;\n        bottom: 18px;\n        opacity: 0.3;\n        display: block;\n      }\n\n      ", "\n\n      ", "\n    "])), asc && (0, _styledComponents.css)(_templateObject5 || (_templateObject5 = (0, _taggedTemplateLiteral2.default)(["\n        ::before {\n          opacity: 1;\n        }\n      "]))), desc && (0, _styledComponents.css)(_templateObject6 || (_templateObject6 = (0, _taggedTemplateLiteral2.default)(["\n        ::after {\n          opacity: 1;\n        }\n      "]))));
});

var Container = _styledComponents.default.div(_templateObject7 || (_templateObject7 = (0, _taggedTemplateLiteral2.default)(["\n  height: 64px;\n  padding: 8px 16px;\n\n  display: flex;\n  justify-content: space-between;\n  align-items: center;\n\n  box-shadow: 0px 0px 1px rgba(40, 41, 61, 0.08),\n    0px 0.5px 2px rgba(96, 97, 112, 0.16);\n"])));

var PaginationInfo = _styledComponents.default.p(_templateObject8 || (_templateObject8 = (0, _taggedTemplateLiteral2.default)(["\n  font-family: ", ";\n  font-size: ", "px;\n\n  color: ", ";\n"])), _styles.typography.type.secondary, _styles.typography.size.s2, _styles.colors.darker);

var TableContainer = _styledComponents.default.div(_templateObject9 || (_templateObject9 = (0, _taggedTemplateLiteral2.default)(["\n  background: ", ";\n"])), _styles.colors.lightest);
/**
 * Table component
 * @param {object} props
 * @returns Table
 */


function Table(_ref6) {
  var columns = _ref6.columns,
      rows = _ref6.rows,
      paging = _ref6.paging,
      showPaging = _ref6.showPaging,
      onChangePage = _ref6.onChangePage,
      ordering = _ref6.ordering,
      onChangeOrder = _ref6.onChangeOrder,
      showSearch = _ref6.showSearch,
      onSearch = _ref6.onSearch,
      searchPlaceholder = _ref6.searchPlaceholder,
      refValue = _ref6.refValue,
      HeaderComponent = _ref6.headerComponent,
      headerTitle = _ref6.headerTitle,
      formatInputProps = _ref6.formatInputProps,
      maskInputProps = _ref6.maskInputProps,
      isNumericInputProps = _ref6.isNumericInputProps;

  var _useState = (0, _react.useState)(""),
      _useState2 = (0, _slicedToArray2.default)(_useState, 2),
      ref = _useState2[0],
      setRef = _useState2[1];

  (0, _react.useEffect)(function () {
    setRef(refValue);
  }, [refValue]);
  var handleSubmit = (0, _react.useCallback)(function (e) {
    e === null || e === void 0 ? void 0 : e.preventDefault();
    onSearch(ref); // setRef('');
  }, [onSearch, ref]);
  var handlePaginateDescription = (0, _react.useCallback)(function (limit, page, total) {
    var numberOfRegisters = limit * page > total ? total : limit * page;
    var totalOfRegisters = total;
    return /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, "Exibindo ", /*#__PURE__*/_react.default.createElement("b", null, numberOfRegisters), " de ", /*#__PURE__*/_react.default.createElement("b", null, totalOfRegisters));
  }, []);
  return /*#__PURE__*/_react.default.createElement(TableContainer, null, headerTitle && /*#__PURE__*/_react.default.createElement("div", {
    style: {
      display: "flex",
      alignContent: "center"
    }
  }, /*#__PURE__*/_react.default.createElement("p", {
    style: {
      fontFamily: _styles.typography.type.secondary,
      color: "#3B3B3A",
      alignContent: "center",
      height: "600",
      fontSize: "24px",
      lineHeight: "32px",
      margin: "16px",
      fontWeight: 600
    }
  }, headerTitle)), /*#__PURE__*/_react.default.createElement(Container, null, showSearch && /*#__PURE__*/_react.default.createElement("div", {
    style: {
      width: 500
    }
  }, /*#__PURE__*/_react.default.createElement("form", {
    onSubmit: handleSubmit
  }, /*#__PURE__*/_react.default.createElement(_Input.Input, {
    value: ref,
    handleChange: function handleChange(e) {
      return setRef(e.target.value);
    },
    placeholder: searchPlaceholder,
    icon: function icon() {
      return /*#__PURE__*/_react.default.createElement(_icons.Search, {
        style: {
          cursor: "pointer"
        },
        htmlColor: "#8A8A8A",
        onClick: handleSubmit
      });
    },
    size: "small",
    fullWidth: true,
    format: formatInputProps,
    mask: maskInputProps,
    isNumeric: isNumericInputProps
  }))), HeaderComponent && /*#__PURE__*/_react.default.createElement(HeaderComponent, null)), /*#__PURE__*/_react.default.createElement(_core.Table, {
    size: "medium"
  }, /*#__PURE__*/_react.default.createElement(_core.TableHead, null, /*#__PURE__*/_react.default.createElement(_core.TableRow, null, columns.map(function (column, index) {
    return /*#__PURE__*/_react.default.createElement(HeaderCell, {
      key: column.id,
      column: column,
      center: index !== 0,
      ordering: ordering,
      onChangeOrder: onChangeOrder
    });
  }))), /*#__PURE__*/_react.default.createElement(_core.TableBody, null, rows.map(function (item, index) {
    return /*#__PURE__*/_react.default.createElement(_core.TableRow, {
      style: {
        borderBottom: "1px solid #E0E0E0"
      },
      key: item.id || index
    }, columns.map(function (column, colIndex) {
      if (column.component) {
        var Component = column.component;
        return /*#__PURE__*/_react.default.createElement(Component, {
          key: column.id,
          item: item,
          column: column
        });
      }

      return /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, /*#__PURE__*/_react.default.createElement(TableCell, {
        center: colIndex !== 0,
        key: column.id
      }, /*#__PURE__*/_react.default.createElement("p", {
        style: {
          color: "#3B3B3A",
          padding: "15px 15px"
        }
      }, item[column.id] || "-")));
    }));
  }))), showPaging && /*#__PURE__*/_react.default.createElement(Container, null, /*#__PURE__*/_react.default.createElement(_Pagination.Pagination, {
    page: paging === null || paging === void 0 ? void 0 : paging.page,
    pages: Math.ceil((paging === null || paging === void 0 ? void 0 : paging.total) / (paging === null || paging === void 0 ? void 0 : paging.limit)),
    paginate: onChangePage
  }), /*#__PURE__*/_react.default.createElement(PaginationInfo, {
    style: {
      fontWeight: 400,
      color: "#8A8A8A"
    }
  }, handlePaginateDescription(paging === null || paging === void 0 ? void 0 : paging.limit, paging === null || paging === void 0 ? void 0 : paging.page, paging === null || paging === void 0 ? void 0 : paging.total))));
}

Table.defaultProps = {
  showPaging: true,
  showSearch: true,
  searchPlaceholder: "Pesquisar",
  refValue: ""
};