"use strict";

var _interopRequireWildcard = require("@babel/runtime/helpers/interopRequireWildcard");

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.TextEditor = TextEditor;

var _slicedToArray2 = _interopRequireDefault(require("@babel/runtime/helpers/esm/slicedToArray"));

var _react = _interopRequireWildcard(require("react"));

var _draftJs = require("draft-js");

var _draftConvert = require("draft-convert");

var _InlineControls = require("./InlineControls");

var _styles = require("./styles");

var _arrays = require("../../utils/arrays");

var allowedCommands = ['backspace', 'backspace-word', 'split-block', 'bold', 'italic'];
/**
  Text editor component
  It returns a HTML formatted text
**/

function TextEditor(_ref) {
  var initialValue = _ref.initialValue,
      onChange = _ref.onChange;
  var ref = (0, _react.useRef)(null);

  var _useState = (0, _react.useState)(initialValue ? function () {
    return _draftJs.EditorState.createWithContent((0, _draftConvert.convertFromHTML)(initialValue));
  } : function () {
    return _draftJs.EditorState.createEmpty();
  }),
      _useState2 = (0, _slicedToArray2.default)(_useState, 2),
      editorState = _useState2[0],
      setEditorState = _useState2[1];

  var handleSetState = (0, _react.useCallback)(function (newState) {
    setEditorState(newState);
    onChange((0, _draftConvert.convertToHTML)(newState.getCurrentContent()));
  }, [onChange]);
  var handleKeyCommand = (0, _react.useCallback)(function (command, state) {
    if (!(0, _arrays.contains)(allowedCommands, command)) return;

    var newState = _draftJs.RichUtils.handleKeyCommand(state, command);

    if (newState) {
      handleSetState(newState);
      return 'handled';
    }

    return 'not-handled';
  }, [handleSetState]);
  var toggleInlineStyle = (0, _react.useCallback)(function (style) {
    var newState = _draftJs.RichUtils.toggleInlineStyle(editorState, style);

    handleSetState(newState);
  }, [editorState, handleSetState]);
  var mapKeyToEditorCommand = (0, _react.useCallback)(function (e) {
    var TAB_CODE = 9;
    var MAX_DEPTH = 4;

    if (e.keyCode === TAB_CODE) {
      var newState = _draftJs.RichUtils.onTab(e, editorState, MAX_DEPTH);

      if (newState !== editorState) handleSetState(newState);
      return;
    }

    return (0, _draftJs.getDefaultKeyBinding)(e);
  }, [editorState, handleSetState]);
  var focus = (0, _react.useCallback)(function () {
    var _ref$current;

    return (_ref$current = ref.current) === null || _ref$current === void 0 ? void 0 : _ref$current.focus();
  }, []);
  return /*#__PURE__*/_react.default.createElement(_styles.Container, null, /*#__PURE__*/_react.default.createElement(_styles.Header, null, /*#__PURE__*/_react.default.createElement(_InlineControls.InlineControls, {
    editorState: editorState,
    onToggle: toggleInlineStyle
  })), /*#__PURE__*/_react.default.createElement(_styles.TextEditorContainer, {
    onClick: focus
  }, /*#__PURE__*/_react.default.createElement(_draftJs.Editor, {
    editorState: editorState,
    handleKeyCommand: handleKeyCommand,
    onChange: handleSetState,
    keyBindingFn: mapKeyToEditorCommand,
    ref: ref,
    spellCheck: true
  })));
}

TextEditor.defaultProps = {
  initialValue: null
};