import React from "react";
import PropTypes from "prop-types";

import { TextField, styled, makeStyles } from "@material-ui/core";
import { Autocomplete as MuiAutocomplete } from "@material-ui/lab";

import { colors, typography } from "../../shared/styles";

const StyledAutocomplete = styled(MuiAutocomplete)({
  fontFamily: typography.type.primary,

  "& label.Mui-focused": {
    color: colors.amulet,
  },

  "& .MuiInput-underline:after": {
    borderBottomColor: colors.amulet,
  },

  "& .MuiOutlinedInput-root": {
    "&:hover fieldset": {
      borderColor: colors.amulet,
    },
    "&.Mui-focused fieldset": {
      borderColor: colors.amulet,
    },
  },
});

const useStyles = makeStyles({
  required: {  
    "& fieldset": {
      borderColor: colors.negative,
    },
  },
});

const CustomAutocomplete = ({...props}) => {
  const classes = useStyles();

  return <StyledAutocomplete className={(props.required && !props.value) && classes.required} {...props} />
};

export function Autocomplete({
  id,
  label,
  options,
  handleChange,
  error,
  value,
  ...props
}) {
  return (
    <CustomAutocomplete
      id={id}
      options={options}
      value={options.find((o) => o.value === value)}
      getOptionLabel={(option) => option.label}
      getOptionSelected={(option, value) => option?.value === value?.value}
      onChange={handleChange}
      fullWidth
      renderInput={(params) => (
        <TextField {...params} label={label} variant="outlined" error={error} />
      )}
      {...props}
    />
  );
}

Autocomplete.propTypes = {
  id: PropTypes.string.isRequired,
  label: PropTypes.string,
  options: PropTypes.arrayOf(PropTypes.shape({
      label: PropTypes.string.isRequired,
      value: PropTypes.oneOfType([
        PropTypes.string,
        PropTypes.number
      ]),
    })).isRequired,
  /**
   * This function must be able to receive 2 params,
   * event and new value respectively
   */
  handleChange: PropTypes.func.isRequired,
  error: PropTypes.bool,
};

Autocomplete.defaultProps = {
  label: 'Pesquisar...',
  error: false,
};
