import React from "react";
import { TextField, styled } from "@material-ui/core";
import PropTypes from "prop-types";
import { colors } from "../../shared/styles";

const TextFieldStyled = styled(TextField)({
  "& label.Mui-focused": {
    color: colors.amulet,
  },
  "& .MuiInput-underline:after": {
    borderBottomColor: colors.amulet,
  },
  "& .MuiOutlinedInput-root": {
    "&:hover fieldset": {
      borderColor: colors.amulet,
    },
    "&.Mui-focused fieldset": {
      borderColor: colors.amulet,
    },
  },
});

export function DataPicker({ dataPickerId, label, handleChange, value }) {
  return (
    <TextFieldStyled
      id={dataPickerId}
      name={dataPickerId}
      label={label}
      type="date"
      variant="outlined"
      size='small'
      onChange={(e) => handleChange(e)}
      value={value}
      InputLabelProps={{
        shrink: true,
      }}
    />
  );
}

DataPicker.propTypes = {
  /**
   * The id provide to input
   */
  dataPickerId: PropTypes.string,
  /**
   * The label above input
   */
  label: PropTypes.string,
  /**
   * Function to handle with value change
   */
  handleChange: PropTypes.func.isRequired,
  /**
   * The value of input / datepicker
   */
  value: PropTypes.string.isRequired,
};

DataPicker.defaultProps = {
  dataPickerId: "defaultPickerId",
  label: "",
};
