import React from "react";
import PropTypes from "prop-types";

import { Card as MuiCard } from "@material-ui/core";
import styled from "styled-components";
// import { MdCloudUpload } from "react-icons/md";

import { useDropzone } from "react-dropzone";
import { SaveAlt } from "@material-ui/icons";

import { colors, typography } from "../../shared/styles";

const Card = styled(MuiCard)`
  height: 345px;
  width: 100%;
  /* width: 176px; */

  padding: 8px;
  box-sizing: border-box;

  font-family: ${typography.type.primary};
  background-color: ${colors.lighter} !important;

  border: 2px dashed #8a8a8a;
  border-radius: 8px !important;

  display: flex;
  justify-content: center;
  align-content: center;
  align-items: center;
  flex-direction: column;
`;

const CardBoldParagraph = styled.p`
  margin: 10px 0px;
  font-size: 24px;
  line-height: 32px;
  text-align: center;
  font-weight: 600;
  color: #8a8a8a;
  margin: 25px 0 5px 0;
`;

const ContentContainer = styled.div`
  height: 100%;
  width: 100%;
  display: flex;
  flex-direction: column;
  align-items: center;
  /* justify-content: space-between; */
  padding: 5px;
  padding-top: 40px;
  cursor: pointer;
`;

const CardParagraph = styled.p`
  font-size: 16px;
  font-weight: 400;
  line-height: 24px;
  color: #8a8a8a;
  text-align: center;
`;

const ListItem = styled.li`
  font-size: ${typography.size.s2}px;
  font-weight: ${typography.weight.regular};
  line-height: 16px;
  color: ${colors.madang};
`;

const CardButton = styled(MuiCard)`
  height: 40px;
  width: 210px;
  cursor: pointer;

  padding: 8px;
  box-sizing: border-box;
  box-shadow: none;

  font-family: ${typography.type.primary};

  border: 2px solid #9cd186;
  border-radius: 8px !important;

  display: flex;
  justify-content: center;
  align-content: center;
  align-items: center;
  flex-direction: column;
`;

const CardButtonBoldParagraph = styled.p`
  display: flex;
  justify-content: center;
  align-items: center;
  margin: 10px 0px;
  font-size: 16px;
  font-weight: 600;
  color: #9cd186;
`;

function CardBody({ files, isDragActive, icon, bodyTitle, bodySubtitle }) {
  if (files.length > 0) {
    return (
      <ul>
        {files.map((file) => (
          <ListItem key={file.name}>{file.name}</ListItem>
        ))}
      </ul>
    );
  }

  if (isDragActive)
    return <CardBoldParagraph>{bodyTitle}</CardBoldParagraph>;

  return (
    <ContentContainer>
      {/* <MdCloudUpload style={{ color: colors.amulet, fontSize: 48 }} /> */}
      {icon && (
        <img
          alt="DragnDropIcon"
          src={icon}
          style={{ width: "50px", height: "50px" }}
        />
      )}

      <CardBoldParagraph>{bodyTitle}</CardBoldParagraph>


      <CardParagraph>
        {bodySubtitle ? bodySubtitle() :
          <>
            <p style={{ margin: "5px 0px" }}>Tamanho maximo: 65kb</p>
            <p style={{ margin: "5px 0px" }}>
              Permitido somente imagens em JPG ou JPEG
            </p>
            <p style={{ margin: "5px 0px" }}>
              A dimensão minima é 1000x1000px e maxima é 3200x3200
            </p>
          </>
        }
      </CardParagraph>
    </ContentContainer>
  );
}

/**
 * Drag and drop file upload component
 * @param {object} props
 * @returns DragAndDrop
 */
export function DragAndDrop({ files, onDrop, icon, isButton, buttonTitle, bodyTitle, bodySubtitle }) {
  const { getRootProps, getInputProps, isDragActive } = useDropzone({ onDrop });

  if (isButton)
    return (
      <CardButton {...getRootProps()}>
        <input {...getInputProps()} />

        <CardButtonBoldParagraph>
          {buttonTitle}&nbsp; <SaveAlt />
        </CardButtonBoldParagraph>
      </CardButton>
    );

  return (
    <Card {...getRootProps()}>
      <input {...getInputProps()} />

      <CardBody isDragActive={isDragActive} files={files} icon={icon} bodyTitle={bodyTitle} bodySubtitle={bodySubtitle} />
    </Card>
  );
}

DragAndDrop.propTypes = {
  /**
   * Array of uploaded files
   */
  files: PropTypes.arrayOf(PropTypes.object),
  /**
   * Function to be called when files are dropped. It must be able to receive
   * a single param corresponding to the accepted files
   */
  onDrop: PropTypes.func.isRequired,
  /**
   * icon for dragNdrop center image
   */
  icon: PropTypes.shape({
    type: PropTypes.oneOf(["img", "svg"]),
  }).isRequired,
  /**
   * boolean to show dragNdrop like button
   */
  isButton: PropTypes.bool,
  /**
   * button title when isButton = true
   */
  buttonTitle: PropTypes.string,
  /**
   * body title when isButton = false
   */
  bodyTitle: PropTypes.string,
  /**
   * body subtitle when isButton = false
   * _EXAMPLE:_
   * const teste = () => {
      return (
        <>
          <p>First P</p>
          <p>Second p</p>
        </>
        )
      }
   */
  bodySubtitle: PropTypes.func,
};

DragAndDrop.defaultProps = {
  files: [],
  isButton: false,
  buttonTitle: 'Inserir Imagens',
  bodyTitle: "Arraste e solte suas imagens aqui :)"
};
