import React, { useState } from 'react';
import PropTypes from 'prop-types';

import { ExpandLess, ExpandMore } from '@material-ui/icons';

import { Notification } from '../Notification';

import { colors } from '../../shared/styles';
import { Container, Button, Content } from './styles';

/**
  Floating tag component.
  It receives a children prop to be rendered in its body if open.
  You can also provide a notification span status.

  Example:
  ```
  <FloatingCard title='Produtos Adicionados' notification='3'>
    <p>something</p>
    <p>something</p>
    <p>something</p>
  </FloatingCard>```
**/
export function FloatingCard({ children, title, notification }) {
  const [open, setOpen] = useState(false);

  return (
    <Container>
      <Button open={open} onClick={() => setOpen(!open)}>
        {title}

        {!open && notification && <Notification text={notification} />}

        {
          open
            ? <ExpandMore htmlColor={colors.amulet} />
            : <ExpandLess htmlColor={colors.amulet} />
        }
      </Button>

      <Content open={open}>
        {children}
      </Content>
    </Container>
  );
}

FloatingCard.propTypes = {
  title: PropTypes.string.isRequired,
  children: PropTypes.any.isRequired,
  notification: PropTypes.oneOfType([
    PropTypes.number,
    PropTypes.string,
    PropTypes.bool
  ]),
};

FloatingCard.defaultProps = {
  notification: false,
};
