import React, { useMemo } from "react";
import PropTypes from "prop-types";

import styled from "styled-components";

import { MdEdit, MdDelete } from 'react-icons/md';
import { Card as MuiCard } from "@material-ui/core";
import { Options } from '../Options';

import { typography, colors } from "../../shared/styles";

const StyledCard = styled(MuiCard)`
  height: 226px;
  width: 176px;
  padding: 8px;

  box-sizing: border-box;

  border: 1px solid #EEEBDD;
  box-shadow: 0px 0px 1px rgba(40, 41, 61, 0.08), 
    0px 0.5px 2px rgba(96, 97, 112, 0.16);

  display: flex;
  flex-direction: column;
  justify-content: space-between;
`;

const CardContent = styled.div`
  width: 160px;
  height: 160px;
  
  display: flex;
  justify-content: center;
`;

const Image = styled.img`
  height: 100%;
  width: 100%;
  object-fit: cover;
  border-radius: 4px;
`;

const Header = styled.header`
  display: flex;
  justify-content: space-between;
  align-items: center;
`;

const Footer = styled.footer`
  display: flex;
  justify-content: center;
  align-items: center;
`;

const Label = styled.span`
  font-family: ${typography.type.secondary};
  font-weight: ${typography.weight.bold};
  font-size: ${typography.size.s1}px;
  line-height: 18px;
  letter-spacing: 0.2px;
  color: ${colors.label};
`;

const Title = styled.span`
  font-family: ${typography.type.secondary};
  font-weight: ${typography.weight.regular};
  font-size: ${typography.size.s1}px;
  line-height: 18px;
  letter-spacing: 0.2px;
  color: ${colors.label};

  overflow: hidden;
  white-space: nowrap;
  text-overflow: ellipsis;
`;

/**
  Default card component to display a single image
**/
export function ImageCard({ title, src, alt, main, onDelete, onSetMain }) {
  const setMainText = useMemo(
    () => main ? 'Tornar secundária' : 'Tornar primária', [main]
  );

  return (
    <StyledCard>
      <Header>
        <Label>{main ? 'Primária' : 'Secundária'}</Label>

        <Options options={[
          { icon: MdEdit, text: setMainText, onClick: onSetMain },
          { icon: MdDelete, text: 'Remover', onClick: onDelete }
        ]} />
      </Header>

      <CardContent>
        <Image alt={alt} src={src} />
      </CardContent>

      <Footer>
        <Title>{title}</Title>
      </Footer>
    </StyledCard>
  );
}

ImageCard.propTypes = {
  /**
   * The text that will be shown on top of the card
   */
  title: PropTypes.string.isRequired,
  /**
   * The source of image to show in the middle of card
   */
  src: PropTypes.any.isRequired,
  /**
   * The text that will be show when image don't load
   */
  alt: PropTypes.string,
  /**
   * Function to execute when click on delete in card
   * U can pass onDelete={function} or onDelete={() => function(param)}
   */
  onDelete: PropTypes.func.isRequired,
  /**
   * Function to set image as main image
   */
  onSetMain: PropTypes.func,
  /**
   * Is this image the main image?
   */
  main: PropTypes.bool,
};

ImageCard.defaultProps = {
  altImage: "Image card",
  onSetMain: null,
  main: false,
};
