import React from "react";
import PropTypes from "prop-types";

import { Modal, Box } from "@material-ui/core";

import { Button } from "../Button";

const style = {
  position: "absolute",
  maxHeight: "85vh",
  top: "50%",
  left: "50%",
  transform: "translate(-50%, -50%)",
  width: "50%",
  bgcolor: "background.paper",
  boxShadow: 24,
  p: 4,
  overflowY: "scroll",
};

export function ModalComponent({
  modalId,
  open,
  setOpen,

  showButton,
  labelButton,
  fullWidthButton,

  children,

  buttonSize,
  ...props
}) {
  const handleOpen = () => setOpen(true);
  const handleClose = () => setOpen(false);

  return (
    <div>
      {showButton && (
        <Button onClick={handleOpen} size={buttonSize} fullWidth={fullWidthButton}>
          {labelButton}
        </Button>
      )}

      <Modal
        id={modalId}
        open={open}
        onClose={handleClose}
        aria-labelledby="modal-modal-title"
        aria-describedby="modal-modal-description"
        {...props}
      >
        <Box sx={style}>{children}</Box>
      </Modal>
    </div>
  );
}

ModalComponent.propTypes = {
  /**
   * The ID from modal
   */
  modalId: PropTypes.string.isRequired,
  /**
   * The label from button
   */
  labelButton: PropTypes.any,
  /**
   * Bool value for button fullWidth or not
   */
  fullWidthButton: PropTypes.bool,
  /**
   * Show modal button
   */
  showButton: PropTypes.bool,
  /**
   * Is modal open
   */
  open: PropTypes.bool,
  /**
   * Function to handle modal open state
   */
  setOpen: PropTypes.func,
   /**
   * The size of the button.
   * Accepted sizes: 'large', 'medium', 'small'
   */
    buttonSize: PropTypes.oneOf(["large", "medium", "small"]),
};

ModalComponent.defaultProps = {
  labelButton: "Label",
  fullWidthButton: false,
  showButton: true,
  open: false,
  buttonSize: "large",
};
