import React, { useState, useRef } from "react";
import PropTypes from "prop-types";

import { Popper } from "@material-ui/core";
import { MdMoreHoriz } from "react-icons/md";
import {
  EditIcon,
  PopperDropdown,
  PopperDropdownItem,
  PopperSpan,
} from "./styles";
import { useRefOutside } from "../../hooks/useRefOutsideClick";

export function Options({ options }) {
  const wrapperRef = useRef(null);
  const [anchorEl, setAnchorEl] = useState(null);

  useRefOutside(wrapperRef, setAnchorEl, null);

  const handleClick = (event) => {
    setAnchorEl(anchorEl ? null : event.currentTarget);
  };

  const open = Boolean(anchorEl);
  const id = open ? "simple-popper" : undefined;

  return (
    <span ref={wrapperRef}>
      <EditIcon size="small" onClick={handleClick}>
        <MdMoreHoriz />
      </EditIcon>

      <Popper id={id} open={open} anchorEl={anchorEl} ref={wrapperRef}>
        <PopperDropdown>
          {options.map(({ icon: Icon, text, onClick }, index) => (
            <PopperDropdownItem key={index} onClick={onClick}>
              <Icon />

              <PopperSpan>
                {text}
              </PopperSpan>
            </PopperDropdownItem>
          ))}
        </PopperDropdown>
      </Popper>
    </span>
  );
}

Options.propTypes = {
  options: PropTypes.arrayOf(
    PropTypes.shape({
      icon: PropTypes.any.isRequired,
      text: PropTypes.string.isRequired,
      onClick: PropTypes.func,
    })
  ).isRequired,
};
