import React from 'react';
import PropTypes from 'prop-types';
import styled from 'styled-components';

import { CancelOutlined } from '@material-ui/icons';

import { colors, typography } from '../../shared/styles';

const TextSpan = styled.span`
  max-width: 120px;
  overflow: hidden;
  white-space: nowrap;
  text-overflow: ellipsis;
`;

const Span = styled.span`
  max-width: 150px;
  height: 18px;
  padding: 4px 8px;
  border-radius: 8px;

  display: inline-flex;
  align-items: center;
  justify-content: space-between;

  font-family: ${typography.type.primary};
  font-size: ${typography.size.s1}px;
  font-weight: ${typography.weight.bold};

  background: ${colors.madang};
  color: ${colors.darkest};
`;

/**
 Single tag
**/
export function Tag({ children, onDelete }) {
  return (
    <Span>
      <TextSpan>{children}</TextSpan>

      {onDelete && (
        <CancelOutlined
          style={{
            height: 17,
            cursor: 'pointer',
            marginLeft: 10,
            paddingBottom: 2
          }}
          onClick={onDelete}
        />
      )}
    </Span>
  );
}

Tag.propTypes = {
  /**
   * The content that will be shown inside the button
   */
  children: PropTypes.string.isRequired,
  /**
   * Delete function
   */
  onDelete: PropTypes.func,
};

Tag.defaultProps = {
  onDelete: null,
};
