import React from 'react';
import PropTypes from 'prop-types';

import { StyledButton } from '../StyledButton';
import { Container } from './styles';

const BLOCK_TYPES = [
  { label: 'H1', style: 'header-one' },
  { label: 'H2', style: 'header-two' },
  { label: 'H3', style: 'header-three' },
  { label: 'H4', style: 'header-four' },
  { label: 'H5', style: 'header-five' },
  { label: 'H6', style: 'header-six' },
  { label: 'UL', style: 'unordered-list-item' },
  { label: 'OL', style: 'ordered-list-item' },
];

export function BlockControls({ onToggle, editorState }) {
  const selection = editorState.getSelection();
  const blockType = editorState
    .getCurrentContent()
    .getBlockForKey(selection.getStartKey())
    .getType();

  return (
    <Container>
      {BLOCK_TYPES.map((type) =>
        <StyledButton
          key={type.label}
          active={type.style === blockType}
          label={type.label}
          onToggle={onToggle}
          style={type.style}
        />
      )}
    </Container>
  );
}

BlockControls.propTypes = {
  /**
   * on toggle inline style button
   */
  onToggle: PropTypes.func.isRequired,
  /**
   * current state of text editor
   */
  editorState: PropTypes.object.isRequired,
};
