import React from 'react';
import PropTypes from 'prop-types';

import { StyledButton } from '../StyledButton';
import { Container } from './styles';

const INLINE_STYLES = [
  { label: 'Bold', style: 'BOLD' },
  { label: 'Italic', style: 'ITALIC' },
];

export function InlineControls({ onToggle, editorState }) {
  const currentStyle = editorState.getCurrentInlineStyle();

  return (
    <Container>
      {INLINE_STYLES.map((type) =>
        <StyledButton
          key={type.label}
          active={currentStyle.has(type.style)}
          label={type.label}
          onToggle={onToggle}
          style={type.style}
        />
      )}
    </Container>
  );
}

InlineControls.propTypes = {
  /**
   * on toggle inline style button
   */
  onToggle: PropTypes.func.isRequired,
  /**
   * current state of text editor
   */
  editorState: PropTypes.object.isRequired,
};
