import React, { useCallback } from 'react';
import PropTypes from 'prop-types';

import { Span } from './styles';

export function StyledButton({ label, active, style, onToggle }) {
  const handleToggle = useCallback((e) => {
    e.preventDefault();

    onToggle(style);
  }, [onToggle, style]);

  return (
    <Span active={active} onMouseDown={handleToggle}>
      {label}
    </Span>
  );
}

StyledButton.propTypes = {
  /**
   * Button label
   */
  label: PropTypes.string.isRequired,
  /**
   * Button current styles
   */
  style: PropTypes.string.isRequired,
  /**
   * Function to be called on button toggle
   */
  onToggle: PropTypes.func.isRequired,
  /**
   * Is button currently active?
   */
  active: PropTypes.bool,
};

StyledButton.defaultProps = {
  active: false,
};
