import React from "react";
import PropTypes from "prop-types";
import { makeStyles } from "@material-ui/core/styles";
import AppBar from "@material-ui/core/AppBar";
import Toolbar from "@material-ui/core/Toolbar";
import Typography from "@material-ui/core/Typography";
import ListItemIcon from "@material-ui/core/ListItemIcon";


const useStyles = makeStyles((theme) => ({
  root: {
    display: "flex",
  },
  appBar: {
    zIndex: theme.zIndex.drawer + 1,
  },
}));

export function ClippedDrawer({ logo, children, backgroundColor }) {
  const classes = useStyles();

  return (
    <div className={classes.root}>
      <AppBar position="fixed" className={classes.appBar}>
        <Toolbar
          style={{
            backgroundColor: backgroundColor,
            maxHeight: "80px",
            display: "flex",
            justifyContent: "space-between",
          }}
        >
          <Typography
            style={{
              color: "black",
              width: "15%",
              margin: 0,
            }}
          >
            {logo && (
              <ListItemIcon>
                <img src={logo} alt="Brand Icon" style={{ height: "50px" }} />
              </ListItemIcon>
            )}
          </Typography>
          <Typography noWrap style={{ color: "black", width: "80%" }}>
            {children}
          </Typography>
        </Toolbar>
      </AppBar>
    </div>
  );
}

ClippedDrawer.propTypes = {
  /**
   * The brandIcon to be with brandLabels
   */
  logo: PropTypes.any,
  /**
   * Color from menu background
   */
  backgroundColor: PropTypes.string,
};

ClippedDrawer.defaultProps = {
  backgroundColor: "#FFF",
};
