import { useEffect } from "react";

export function useRefOutside(ref, stateToSet, valueToSet) {
  useEffect(() => {
    /**
     * Set state to false if clicked on outside of element
     */
    function handleClickOutside(event) {
      if (ref.current && !ref.current.contains(event.target)) {
        stateToSet(valueToSet);
      }
    }
    // Bind the event listener
    document.addEventListener("mousedown", handleClickOutside);
    return () => {
      // Unbind the event listener on clean up
      document.removeEventListener("mousedown", handleClickOutside);
    };
  }, [ref, stateToSet, valueToSet]);
}
